# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.predictionstore.v1 import predictionstore_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2


class PredictionStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ingest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService/Ingest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.FromString,
                )


class PredictionStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ingest(self, request, context):
        """upload the current prediction database to the cloud.
        The archived prediction will turn into a predicted dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PredictionStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ingest': grpc.unary_unary_rpc_method_handler(
                    servicer.Ingest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PredictionStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ingest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionStoreService/Ingest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionsIngestRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_predictionstore_dot_v1_dot_predictionstore__pb2.PredictionIngestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
