# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.runbook.v1 import runbook_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2


class RunBookServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRunBooks = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/ListRunBooks',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.FromString,
                )
        self.CreateRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/CreateRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.FromString,
                )
        self.GetRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/GetRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.FromString,
                )
        self.UpdateRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/UpdateRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.FromString,
                )
        self.DeleteRunBook = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/DeleteRunBook',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.FromString,
                )


class RunBookServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListRunBooks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRunBook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunBookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRunBooks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRunBooks,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.SerializeToString,
            ),
            'CreateRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.SerializeToString,
            ),
            'GetRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.SerializeToString,
            ),
            'UpdateRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.SerializeToString,
            ),
            'DeleteRunBook': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRunBook,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.runbook.v1.RunBookService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RunBookService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListRunBooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/ListRunBooks',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.ListRunBooksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/CreateRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.CreateRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/GetRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.GetRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/UpdateRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.UpdateRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRunBook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.runbook.v1.RunBookService/DeleteRunBook',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_runbook_dot_v1_dot_runbook__pb2.DeleteRunBookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
