# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/util/intstr/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3k8s.io/apimachinery/pkg/util/intstr/generated.proto\x12#k8s.io.apimachinery.pkg.util.intstr\";\n\x0bIntOrString\x12\x0c\n\x04type\x18\x01 \x01(\x03\x12\x0e\n\x06intVal\x18\x02 \x01(\x05\x12\x0e\n\x06strVal\x18\x03 \x01(\tB%Z#k8s.io/apimachinery/pkg/util/intstr')



_INTORSTRING = DESCRIPTOR.message_types_by_name['IntOrString']
IntOrString = _reflection.GeneratedProtocolMessageType('IntOrString', (_message.Message,), {
  'DESCRIPTOR' : _INTORSTRING,
  '__module__' : 'k8s.io.apimachinery.pkg.util.intstr.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.util.intstr.IntOrString)
  })
_sym_db.RegisterMessage(IntOrString)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z#k8s.io/apimachinery/pkg/util/intstr'
  _INTORSTRING._serialized_start=92
  _INTORSTRING._serialized_end=151
# @@protoc_insertion_point(module_scope)
