# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelclassrun.v1 import modelclassrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2


class ModelClassRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelClassRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ListModelClassRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.FromString,
                )
        self.CreateModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/CreateModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.FromString,
                )
        self.GetModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/GetModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.FromString,
                )
        self.UpdateModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/UpdateModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.FromString,
                )
        self.DeleteModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DeleteModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.FromString,
                )
        self.ApproveModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ApproveModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.FromString,
                )
        self.DenyModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DenyModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.FromString,
                )
        self.AbortModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/AbortModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.FromString,
                )
        self.PauseModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/PauseModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.FromString,
                )
        self.ResumeModelClassRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ResumeModelClassRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.FromString,
                )


class ModelClassRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelClassRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenyModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeModelClassRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelClassRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelClassRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelClassRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.SerializeToString,
            ),
            'CreateModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.SerializeToString,
            ),
            'GetModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.SerializeToString,
            ),
            'UpdateModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.SerializeToString,
            ),
            'DeleteModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.SerializeToString,
            ),
            'ApproveModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.SerializeToString,
            ),
            'DenyModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DenyModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.SerializeToString,
            ),
            'AbortModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.SerializeToString,
            ),
            'PauseModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.SerializeToString,
            ),
            'ResumeModelClassRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeModelClassRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelClassRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelClassRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ListModelClassRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ListModelClassRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/CreateModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.CreateModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/GetModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.GetModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/UpdateModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.UpdateModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DeleteModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DeleteModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApproveModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ApproveModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ApproveModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenyModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/DenyModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.DenyModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/AbortModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.AbortModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/PauseModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.PauseModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeModelClassRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunService/ResumeModelClassRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclassrun_dot_v1_dot_modelclassrun__pb2.ResumeModelClassRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
