# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelclassrun/v1/modelclassrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/modelclassrun/v1/modelclassrun.proto\x12\x37github.com.metaprov.modelaapi.services.modelclassrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x86\x02\n\x19ListModelClassRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x1aListModelClassRunsResponse\x12\x63\n\x0emodelclassruns\x18\x01 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15ModelClassRunResponse\"|\n\x1a\x43reateModelClassRunRequest\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"\x1d\n\x1b\x43reateModelClassRunResponse\"\xac\x01\n\x1aUpdateModelClassRunRequest\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateModelClassRunResponse\":\n\x17GetModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\x18GetModelClassRunResponse\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteModelClassRunResponse\"^\n\x1b\x41pproveModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1e\n\x1c\x41pproveModelClassRunResponse\"[\n\x18\x44\x65nyModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1b\n\x19\x44\x65nyModelClassRunResponse\"\x1c\n\x1aPauseModelClassRunResponse\"<\n\x19PauseModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumeModelClassRunResponse\"=\n\x1aResumeModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x41\x62ortModelClassRunResponse\"<\n\x19\x41\x62ortModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xaf\x13\n\x14ModelClassRunService\x12\xe5\x01\n\x12ListModelClassRuns\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/modelclassruns/{namespace}\x12\xdf\x01\n\x13\x43reateModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/modelclassruns:\x01*\x12\xe6\x01\n\x10GetModelClassRun\x12P.github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunRequest\x1aQ.github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/modelclassruns/{namespace}/{name}\x12\xa0\x02\n\x13UpdateModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/modelclassruns/{modelclassrun.metadata.namespace}/{modelclassrun.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/modelclassruns/{namespace}/{name}\x12\xfa\x01\n\x14\x41pproveModelClassRun\x12T.github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunRequest\x1aU.github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunResponse\"5\x82\xd3\xe4\x93\x02/\x1a-/v1/modelclassruns/{namespace}/{name}:approve\x12\xee\x01\n\x11\x44\x65nyModelClassRun\x12Q.github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunRequest\x1aR.github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunResponse\"2\x82\xd3\xe4\x93\x02,\x1a*/v1/modelclassruns/{namespace}/{name}:deny\x12\xf2\x01\n\x12\x41\x62ortModelClassRun\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunResponse\"3\x82\xd3\xe4\x93\x02-\x1a+/v1/modelclassruns/{namespace}/{name}:abort\x12\xf2\x01\n\x12PauseModelClassRun\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunResponse\"3\x82\xd3\xe4\x93\x02-\x1a+/v1/modelclassruns/{namespace}/{name}:pause\x12\xf6\x01\n\x13ResumeModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunResponse\"4\x82\xd3\xe4\x93\x02.\x1a,/v1/modelclassruns/{namespace}/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/modelclassrun/v1b\x06proto3')



_LISTMODELCLASSRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelClassRunsRequest']
_LISTMODELCLASSRUNSREQUEST_LABELSENTRY = _LISTMODELCLASSRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELCLASSRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelClassRunsResponse']
_MODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ModelClassRunResponse']
_CREATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassRunRequest']
_CREATEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelClassRunResponse']
_UPDATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelClassRunRequest']
_UPDATEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelClassRunResponse']
_GETMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassRunRequest']
_GETMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetModelClassRunResponse']
_DELETEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelClassRunRequest']
_DELETEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelClassRunResponse']
_APPROVEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['ApproveModelClassRunRequest']
_APPROVEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ApproveModelClassRunResponse']
_DENYMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['DenyModelClassRunRequest']
_DENYMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['DenyModelClassRunResponse']
_PAUSEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['PauseModelClassRunResponse']
_PAUSEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['PauseModelClassRunRequest']
_RESUMEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelClassRunResponse']
_RESUMEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelClassRunRequest']
_ABORTMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['AbortModelClassRunResponse']
_ABORTMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['AbortModelClassRunRequest']
ListModelClassRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelClassRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCLASSRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCLASSRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest)
  })
_sym_db.RegisterMessage(ListModelClassRunsRequest)
_sym_db.RegisterMessage(ListModelClassRunsRequest.LabelsEntry)

ListModelClassRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelClassRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsResponse)
  })
_sym_db.RegisterMessage(ListModelClassRunsResponse)

ModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunResponse)
  })
_sym_db.RegisterMessage(ModelClassRunResponse)

CreateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunRequest)
  })
_sym_db.RegisterMessage(CreateModelClassRunRequest)

CreateModelClassRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunResponse)
  })
_sym_db.RegisterMessage(CreateModelClassRunResponse)

UpdateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelClassRunRequest)

UpdateModelClassRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelClassRunResponse)

GetModelClassRunRequest = _reflection.GeneratedProtocolMessageType('GetModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunRequest)
  })
_sym_db.RegisterMessage(GetModelClassRunRequest)

GetModelClassRunResponse = _reflection.GeneratedProtocolMessageType('GetModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunResponse)
  })
_sym_db.RegisterMessage(GetModelClassRunResponse)

DeleteModelClassRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelClassRunRequest)

DeleteModelClassRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelClassRunResponse)

ApproveModelClassRunRequest = _reflection.GeneratedProtocolMessageType('ApproveModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunRequest)
  })
_sym_db.RegisterMessage(ApproveModelClassRunRequest)

ApproveModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ApproveModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunResponse)
  })
_sym_db.RegisterMessage(ApproveModelClassRunResponse)

DenyModelClassRunRequest = _reflection.GeneratedProtocolMessageType('DenyModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunRequest)
  })
_sym_db.RegisterMessage(DenyModelClassRunRequest)

DenyModelClassRunResponse = _reflection.GeneratedProtocolMessageType('DenyModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunResponse)
  })
_sym_db.RegisterMessage(DenyModelClassRunResponse)

PauseModelClassRunResponse = _reflection.GeneratedProtocolMessageType('PauseModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunResponse)
  })
_sym_db.RegisterMessage(PauseModelClassRunResponse)

PauseModelClassRunRequest = _reflection.GeneratedProtocolMessageType('PauseModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunRequest)
  })
_sym_db.RegisterMessage(PauseModelClassRunRequest)

ResumeModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ResumeModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunResponse)
  })
_sym_db.RegisterMessage(ResumeModelClassRunResponse)

ResumeModelClassRunRequest = _reflection.GeneratedProtocolMessageType('ResumeModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunRequest)
  })
_sym_db.RegisterMessage(ResumeModelClassRunRequest)

AbortModelClassRunResponse = _reflection.GeneratedProtocolMessageType('AbortModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunResponse)
  })
_sym_db.RegisterMessage(AbortModelClassRunResponse)

AbortModelClassRunRequest = _reflection.GeneratedProtocolMessageType('AbortModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunRequest)
  })
_sym_db.RegisterMessage(AbortModelClassRunRequest)

_MODELCLASSRUNSERVICE = DESCRIPTOR.services_by_name['ModelClassRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/modelclassrun/v1'
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._options = None
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELCLASSRUNSERVICE.methods_by_name['ListModelClassRuns']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ListModelClassRuns']._serialized_options = b'\202\323\344\223\002 \022\036/v1/modelclassruns/{namespace}'
  _MODELCLASSRUNSERVICE.methods_by_name['CreateModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['CreateModelClassRun']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/modelclassruns:\001*'
  _MODELCLASSRUNSERVICE.methods_by_name['GetModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['GetModelClassRun']._serialized_options = b'\202\323\344\223\002\'\022%/v1/modelclassruns/{namespace}/{name}'
  _MODELCLASSRUNSERVICE.methods_by_name['UpdateModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['UpdateModelClassRun']._serialized_options = b'\202\323\344\223\002X\032S/v1/modelclassruns/{modelclassrun.metadata.namespace}/{modelclassrun.metadata.name}:\001*'
  _MODELCLASSRUNSERVICE.methods_by_name['DeleteModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['DeleteModelClassRun']._serialized_options = b'\202\323\344\223\002\'*%/v1/modelclassruns/{namespace}/{name}'
  _MODELCLASSRUNSERVICE.methods_by_name['ApproveModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ApproveModelClassRun']._serialized_options = b'\202\323\344\223\002/\032-/v1/modelclassruns/{namespace}/{name}:approve'
  _MODELCLASSRUNSERVICE.methods_by_name['DenyModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['DenyModelClassRun']._serialized_options = b'\202\323\344\223\002,\032*/v1/modelclassruns/{namespace}/{name}:deny'
  _MODELCLASSRUNSERVICE.methods_by_name['AbortModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['AbortModelClassRun']._serialized_options = b'\202\323\344\223\002-\032+/v1/modelclassruns/{namespace}/{name}:abort'
  _MODELCLASSRUNSERVICE.methods_by_name['PauseModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['PauseModelClassRun']._serialized_options = b'\202\323\344\223\002-\032+/v1/modelclassruns/{namespace}/{name}:pause'
  _MODELCLASSRUNSERVICE.methods_by_name['ResumeModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ResumeModelClassRun']._serialized_options = b'\202\323\344\223\002.\032,/v1/modelclassruns/{namespace}/{name}:resume'
  _LISTMODELCLASSRUNSREQUEST._serialized_start=275
  _LISTMODELCLASSRUNSREQUEST._serialized_end=537
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_start=492
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_end=537
  _LISTMODELCLASSRUNSRESPONSE._serialized_start=540
  _LISTMODELCLASSRUNSRESPONSE._serialized_end=694
  _MODELCLASSRUNRESPONSE._serialized_start=696
  _MODELCLASSRUNRESPONSE._serialized_end=719
  _CREATEMODELCLASSRUNREQUEST._serialized_start=721
  _CREATEMODELCLASSRUNREQUEST._serialized_end=845
  _CREATEMODELCLASSRUNRESPONSE._serialized_start=847
  _CREATEMODELCLASSRUNRESPONSE._serialized_end=876
  _UPDATEMODELCLASSRUNREQUEST._serialized_start=879
  _UPDATEMODELCLASSRUNREQUEST._serialized_end=1051
  _UPDATEMODELCLASSRUNRESPONSE._serialized_start=1053
  _UPDATEMODELCLASSRUNRESPONSE._serialized_end=1082
  _GETMODELCLASSRUNREQUEST._serialized_start=1084
  _GETMODELCLASSRUNREQUEST._serialized_end=1142
  _GETMODELCLASSRUNRESPONSE._serialized_start=1145
  _GETMODELCLASSRUNRESPONSE._serialized_end=1281
  _DELETEMODELCLASSRUNREQUEST._serialized_start=1283
  _DELETEMODELCLASSRUNREQUEST._serialized_end=1344
  _DELETEMODELCLASSRUNRESPONSE._serialized_start=1346
  _DELETEMODELCLASSRUNRESPONSE._serialized_end=1375
  _APPROVEMODELCLASSRUNREQUEST._serialized_start=1377
  _APPROVEMODELCLASSRUNREQUEST._serialized_end=1471
  _APPROVEMODELCLASSRUNRESPONSE._serialized_start=1473
  _APPROVEMODELCLASSRUNRESPONSE._serialized_end=1503
  _DENYMODELCLASSRUNREQUEST._serialized_start=1505
  _DENYMODELCLASSRUNREQUEST._serialized_end=1596
  _DENYMODELCLASSRUNRESPONSE._serialized_start=1598
  _DENYMODELCLASSRUNRESPONSE._serialized_end=1625
  _PAUSEMODELCLASSRUNRESPONSE._serialized_start=1627
  _PAUSEMODELCLASSRUNRESPONSE._serialized_end=1655
  _PAUSEMODELCLASSRUNREQUEST._serialized_start=1657
  _PAUSEMODELCLASSRUNREQUEST._serialized_end=1717
  _RESUMEMODELCLASSRUNRESPONSE._serialized_start=1719
  _RESUMEMODELCLASSRUNRESPONSE._serialized_end=1748
  _RESUMEMODELCLASSRUNREQUEST._serialized_start=1750
  _RESUMEMODELCLASSRUNREQUEST._serialized_end=1811
  _ABORTMODELCLASSRUNRESPONSE._serialized_start=1813
  _ABORTMODELCLASSRUNRESPONSE._serialized_end=1841
  _ABORTMODELCLASSRUNREQUEST._serialized_start=1843
  _ABORTMODELCLASSRUNREQUEST._serialized_end=1903
  _MODELCLASSRUNSERVICE._serialized_start=1906
  _MODELCLASSRUNSERVICE._serialized_end=4385
# @@protoc_insertion_point(module_scope)
