# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCgithub.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto\x12\x33github.com.metaprov.modelaapi.services.reciperun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xfa\x01\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x16ListRecipeRunsResponse\x12W\n\nreciperuns\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x16\x43reateRecipeRunRequest\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x19\n\x17\x43reateRecipeRunResponse\"\x9c\x01\n\x16UpdateRecipeRunRequest\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x19\n\x17UpdateRecipeRunResponse\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x14GetRecipeRunResponse\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteRecipeRunResponse2\xda\x08\n\x10RecipeRunService\x12\xcd\x01\n\x0eListRecipeRuns\x12J.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest\x1aK.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/reciperuns/{namespace}\x12\xc7\x01\n\x0f\x43reateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/reciperuns:\x01*\x12\xce\x01\n\x0cGetRecipeRun\x12H.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest\x1aI.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/reciperuns/{namespace}/{name}\x12\x80\x02\n\x0fUpdateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse\"R\x82\xd3\xe4\x93\x02L\x1aG/v1/reciperuns/{reciperun.metadata.namespace}/{reciperun.metadata.name}:\x01*\x12\xd7\x01\n\x0f\x44\x65leteRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse\")\x82\xd3\xe4\x93\x02#*!/v1/reciperuns/{namespace}/{name}B5Z3github.com/metaprov/modelaapi/services/reciperun/v1b\x06proto3')



_LISTRECIPERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest']
_LISTRECIPERUNSREQUEST_LABELSENTRY = _LISTRECIPERUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTRECIPERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse']
_CREATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest']
_CREATERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateRecipeRunResponse']
_UPDATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest']
_UPDATERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateRecipeRunResponse']
_GETRECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRunRequest']
_GETRECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetRecipeRunResponse']
_DELETERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest']
_DELETERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteRecipeRunResponse']
ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRECIPERUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)
_sym_db.RegisterMessage(ListRecipeRunsRequest.LabelsEntry)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

CreateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('CreateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse)
  })
_sym_db.RegisterMessage(CreateRecipeRunResponse)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

UpdateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse)
  })
_sym_db.RegisterMessage(UpdateRecipeRunResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

GetRecipeRunResponse = _reflection.GeneratedProtocolMessageType('GetRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse)
  })
_sym_db.RegisterMessage(GetRecipeRunResponse)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

DeleteRecipeRunResponse = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse)
  })
_sym_db.RegisterMessage(DeleteRecipeRunResponse)

_RECIPERUNSERVICE = DESCRIPTOR.services_by_name['RecipeRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/metaprov/modelaapi/services/reciperun/v1'
  _LISTRECIPERUNSREQUEST_LABELSENTRY._options = None
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RECIPERUNSERVICE.methods_by_name['ListRecipeRuns']._options = None
  _RECIPERUNSERVICE.methods_by_name['ListRecipeRuns']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/reciperuns/{namespace}'
  _RECIPERUNSERVICE.methods_by_name['CreateRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['CreateRecipeRun']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/reciperuns:\001*'
  _RECIPERUNSERVICE.methods_by_name['GetRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['GetRecipeRun']._serialized_options = b'\202\323\344\223\002#\022!/v1/reciperuns/{namespace}/{name}'
  _RECIPERUNSERVICE.methods_by_name['UpdateRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['UpdateRecipeRun']._serialized_options = b'\202\323\344\223\002L\032G/v1/reciperuns/{reciperun.metadata.namespace}/{reciperun.metadata.name}:\001*'
  _RECIPERUNSERVICE.methods_by_name['DeleteRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['DeleteRecipeRun']._serialized_options = b'\202\323\344\223\002#*!/v1/reciperuns/{namespace}/{name}'
  _LISTRECIPERUNSREQUEST._serialized_start=259
  _LISTRECIPERUNSREQUEST._serialized_end=509
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_start=464
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_end=509
  _LISTRECIPERUNSRESPONSE._serialized_start=512
  _LISTRECIPERUNSRESPONSE._serialized_end=650
  _CREATERECIPERUNREQUEST._serialized_start=652
  _CREATERECIPERUNREQUEST._serialized_end=760
  _CREATERECIPERUNRESPONSE._serialized_start=762
  _CREATERECIPERUNRESPONSE._serialized_end=787
  _UPDATERECIPERUNREQUEST._serialized_start=790
  _UPDATERECIPERUNREQUEST._serialized_end=946
  _UPDATERECIPERUNRESPONSE._serialized_start=948
  _UPDATERECIPERUNRESPONSE._serialized_end=973
  _GETRECIPERUNREQUEST._serialized_start=975
  _GETRECIPERUNREQUEST._serialized_end=1029
  _GETRECIPERUNRESPONSE._serialized_start=1031
  _GETRECIPERUNRESPONSE._serialized_end=1151
  _DELETERECIPERUNREQUEST._serialized_start=1153
  _DELETERECIPERUNREQUEST._serialized_end=1210
  _DELETERECIPERUNRESPONSE._serialized_start=1212
  _DELETERECIPERUNRESPONSE._serialized_end=1237
  _RECIPERUNSERVICE._serialized_start=1240
  _RECIPERUNSERVICE._serialized_end=2354
# @@protoc_insertion_point(module_scope)
