# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/attachment/v1/attachment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/attachment/v1/attachment.proto\x12\x34github.com.metaprov.modelaapi.services.attachment.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xfd\x01\n\x16ListAttachmentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\x17ListAttachmentsResponse\x12Z\n\x0b\x61ttachments\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AttachmentList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x14\n\x12\x41ttachmentResponse\"p\n\x17\x43reateAttachmentRequest\x12U\n\nattachment\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\"\x1a\n\x18\x43reateAttachmentResponse\"\xa0\x01\n\x17UpdateAttachmentRequest\x12U\n\nattachment\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateAttachmentResponse\"7\n\x14GetAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x15GetAttachmentResponse\x12U\n\nattachment\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Attachment\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"A\n\x1eGetAttachmentNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x1fGetAttachmentNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\":\n\x17\x44\x65leteAttachmentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteAttachmentResponse\"\x1a\n\x18\x41ttachmentCreateResponse2\xfb\x08\n\x11\x41ttachmentService\x12\xd3\x01\n\x0fListAttachments\x12L.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest\x1aM.github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/attachments/{namespace}\x12\xcd\x01\n\x10\x43reateAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/attachments:\x01*\x12\xd4\x01\n\rGetAttachment\x12J.github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest\x1aK.github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/attachments/{namespace}/{name}\x12\x88\x02\n\x10UpdateAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/attachments/{attachment.metadata.namespace}/{attachment.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteAttachment\x12M.github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest\x1aN.github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/attachments/{namespace}/{name}B6Z4github.com/metaprov/modelaapi/services/attachment/v1b\x06proto3')



_LISTATTACHMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListAttachmentsRequest']
_LISTATTACHMENTSREQUEST_LABELSENTRY = _LISTATTACHMENTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTATTACHMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAttachmentsResponse']
_ATTACHMENTRESPONSE = DESCRIPTOR.message_types_by_name['AttachmentResponse']
_CREATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['CreateAttachmentRequest']
_CREATEATTACHMENTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAttachmentResponse']
_UPDATEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAttachmentRequest']
_UPDATEATTACHMENTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAttachmentResponse']
_GETATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['GetAttachmentRequest']
_GETATTACHMENTRESPONSE = DESCRIPTOR.message_types_by_name['GetAttachmentResponse']
_GETATTACHMENTNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetAttachmentNamespacesRequest']
_GETATTACHMENTNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetAttachmentNamespacesResponse']
_DELETEATTACHMENTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAttachmentRequest']
_DELETEATTACHMENTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAttachmentResponse']
_ATTACHMENTCREATERESPONSE = DESCRIPTOR.message_types_by_name['AttachmentCreateResponse']
ListAttachmentsRequest = _reflection.GeneratedProtocolMessageType('ListAttachmentsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTATTACHMENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTATTACHMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsRequest)
  })
_sym_db.RegisterMessage(ListAttachmentsRequest)
_sym_db.RegisterMessage(ListAttachmentsRequest.LabelsEntry)

ListAttachmentsResponse = _reflection.GeneratedProtocolMessageType('ListAttachmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTATTACHMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.ListAttachmentsResponse)
  })
_sym_db.RegisterMessage(ListAttachmentsResponse)

AttachmentResponse = _reflection.GeneratedProtocolMessageType('AttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentResponse)
  })
_sym_db.RegisterMessage(AttachmentResponse)

CreateAttachmentRequest = _reflection.GeneratedProtocolMessageType('CreateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentRequest)
  })
_sym_db.RegisterMessage(CreateAttachmentRequest)

CreateAttachmentResponse = _reflection.GeneratedProtocolMessageType('CreateAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.CreateAttachmentResponse)
  })
_sym_db.RegisterMessage(CreateAttachmentResponse)

UpdateAttachmentRequest = _reflection.GeneratedProtocolMessageType('UpdateAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentRequest)
  })
_sym_db.RegisterMessage(UpdateAttachmentRequest)

UpdateAttachmentResponse = _reflection.GeneratedProtocolMessageType('UpdateAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.UpdateAttachmentResponse)
  })
_sym_db.RegisterMessage(UpdateAttachmentResponse)

GetAttachmentRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentRequest)
  })
_sym_db.RegisterMessage(GetAttachmentRequest)

GetAttachmentResponse = _reflection.GeneratedProtocolMessageType('GetAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentResponse)
  })
_sym_db.RegisterMessage(GetAttachmentResponse)

GetAttachmentNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAttachmentNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAttachmentNamespacesRequest)

GetAttachmentNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAttachmentNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETATTACHMENTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.GetAttachmentNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAttachmentNamespacesResponse)

DeleteAttachmentRequest = _reflection.GeneratedProtocolMessageType('DeleteAttachmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentRequest)
  })
_sym_db.RegisterMessage(DeleteAttachmentRequest)

DeleteAttachmentResponse = _reflection.GeneratedProtocolMessageType('DeleteAttachmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEATTACHMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.DeleteAttachmentResponse)
  })
_sym_db.RegisterMessage(DeleteAttachmentResponse)

AttachmentCreateResponse = _reflection.GeneratedProtocolMessageType('AttachmentCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHMENTCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.attachment.v1.attachment_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.attachment.v1.AttachmentCreateResponse)
  })
_sym_db.RegisterMessage(AttachmentCreateResponse)

_ATTACHMENTSERVICE = DESCRIPTOR.services_by_name['AttachmentService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/attachment/v1'
  _LISTATTACHMENTSREQUEST_LABELSENTRY._options = None
  _LISTATTACHMENTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ATTACHMENTSERVICE.methods_by_name['ListAttachments']._options = None
  _ATTACHMENTSERVICE.methods_by_name['ListAttachments']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/attachments/{namespace}'
  _ATTACHMENTSERVICE.methods_by_name['CreateAttachment']._options = None
  _ATTACHMENTSERVICE.methods_by_name['CreateAttachment']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/attachments:\001*'
  _ATTACHMENTSERVICE.methods_by_name['GetAttachment']._options = None
  _ATTACHMENTSERVICE.methods_by_name['GetAttachment']._serialized_options = b'\202\323\344\223\002$\022\"/v1/attachments/{namespace}/{name}'
  _ATTACHMENTSERVICE.methods_by_name['UpdateAttachment']._options = None
  _ATTACHMENTSERVICE.methods_by_name['UpdateAttachment']._serialized_options = b'\202\323\344\223\002O\032J/v1/attachments/{attachment.metadata.namespace}/{attachment.metadata.name}:\001*'
  _ATTACHMENTSERVICE.methods_by_name['DeleteAttachment']._options = None
  _ATTACHMENTSERVICE.methods_by_name['DeleteAttachment']._serialized_options = b'\202\323\344\223\002$*\"/v1/attachments/{namespace}/{name}'
  _LISTATTACHMENTSREQUEST._serialized_start=326
  _LISTATTACHMENTSREQUEST._serialized_end=579
  _LISTATTACHMENTSREQUEST_LABELSENTRY._serialized_start=534
  _LISTATTACHMENTSREQUEST_LABELSENTRY._serialized_end=579
  _LISTATTACHMENTSRESPONSE._serialized_start=582
  _LISTATTACHMENTSRESPONSE._serialized_end=724
  _ATTACHMENTRESPONSE._serialized_start=726
  _ATTACHMENTRESPONSE._serialized_end=746
  _CREATEATTACHMENTREQUEST._serialized_start=748
  _CREATEATTACHMENTREQUEST._serialized_end=860
  _CREATEATTACHMENTRESPONSE._serialized_start=862
  _CREATEATTACHMENTRESPONSE._serialized_end=888
  _UPDATEATTACHMENTREQUEST._serialized_start=891
  _UPDATEATTACHMENTREQUEST._serialized_end=1051
  _UPDATEATTACHMENTRESPONSE._serialized_start=1053
  _UPDATEATTACHMENTRESPONSE._serialized_end=1079
  _GETATTACHMENTREQUEST._serialized_start=1081
  _GETATTACHMENTREQUEST._serialized_end=1136
  _GETATTACHMENTRESPONSE._serialized_start=1138
  _GETATTACHMENTRESPONSE._serialized_end=1262
  _GETATTACHMENTNAMESPACESREQUEST._serialized_start=1264
  _GETATTACHMENTNAMESPACESREQUEST._serialized_end=1329
  _GETATTACHMENTNAMESPACESRESPONSE._serialized_start=1331
  _GETATTACHMENTNAMESPACESRESPONSE._serialized_end=1449
  _DELETEATTACHMENTREQUEST._serialized_start=1451
  _DELETEATTACHMENTREQUEST._serialized_end=1509
  _DELETEATTACHMENTRESPONSE._serialized_start=1511
  _DELETEATTACHMENTRESPONSE._serialized_end=1537
  _ATTACHMENTCREATERESPONSE._serialized_start=1539
  _ATTACHMENTCREATERESPONSE._serialized_end=1565
  _ATTACHMENTSERVICE._serialized_start=1568
  _ATTACHMENTSERVICE._serialized_end=2715
# @@protoc_insertion_point(module_scope)
